Weblate source code
===================

Weblate is developed on `GitHub <https://github.com/WeblateOrg/weblate>`_. You
are welcome to fork the code and open pull requests. Patches in any other form
are welcome too.

.. seealso::

    Check out :ref:`internals` to see how Weblate looks from inside.

.. _owasp:

.. include:: snippets/code-guide.rst

.. include:: snippets/pre-commit.rst
